@@ -1072,6 +1072,149 @@ class WM_OT_addon_userpref_show(bpy_types.Operator):
         pass
 
 
+class WM_OT_app_template_install(bpy_types.Operator):
+    bl_idname = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    filepath = None
+    ''' '''
+
+    filter_folder = None
+    ''' '''
+
+    filter_glob = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    order = None
+    ''' '''
+
+    overwrite = None
+    ''' '''
+
+    def as_keywords(self, ignore):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def execute(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def invoke(self, context, event):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
 class WM_OT_appconfig_activate(bpy_types.Operator):
     bl_idname = None
     ''' '''
@@ -6850,6 +6993,14 @@ def execute_context_assign(context):
     pass
 
 
+def module_filesystem_remove(path_base, module_name):
+    ''' 
+
+    '''
+
+    pass
+
+
 def operator_path_is_undo(context, data_path):
     ''' 
 
