@@ -63,6 +63,12 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -111,7 +117,8 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -219,6 +226,12 @@ class OBJECT_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -409,6 +422,12 @@ class OBJECT_PT_context_object(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -556,6 +575,12 @@ class OBJECT_PT_custom_props(ObjectButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -706,6 +731,12 @@ class OBJECT_PT_delta_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -847,6 +878,12 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -988,6 +1025,12 @@ class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1129,6 +1172,12 @@ class OBJECT_PT_groups(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1270,6 +1319,12 @@ class OBJECT_PT_relations(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1414,6 +1469,12 @@ class OBJECT_PT_relations_extras(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1555,6 +1616,12 @@ class OBJECT_PT_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1699,6 +1766,12 @@ class OBJECT_PT_transform_locks(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
