@@ -49,6 +49,7 @@ def beautify_fill(bm: 'bmesh.types.BMesh',
     :type use_restrict_tag: bool
     :param method: method to define what is beautiful
     :type method: int
+    :rtype: dict
     :return: - geom : new flipped faces and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -56,8 +57,8 @@ def beautify_fill(bm: 'bmesh.types.BMesh',
 
 
 def bevel(bm: 'bmesh.types.BMesh',
-          geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                             List['bmesh.types.BMVert'], typing.
+          geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                             List['bmesh.types.BMEdge'], typing.
                              List['bmesh.types.BMFace']], offset: float,
           offset_type: int, segments: int, profile: float, vertex_only: bool,
           clamp_overlap: bool, material: int, loop_slide: bool) -> dict:
@@ -66,7 +67,7 @@ def bevel(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input edges and vertices
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param offset: amount to offset beveled edge
     :type offset: float
     :param offset_type: how to measure offset (enum)
@@ -83,6 +84,7 @@ def bevel(bm: 'bmesh.types.BMesh',
     :type material: int
     :param loop_slide: prefer to slide along edges to having even widths
     :type loop_slide: bool
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace ) - edges : output edges **type** list of ( bmesh.types.BMEdge ) - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -102,6 +104,7 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
     :type cuts: int
     :param edge_percents: Undocumented.
     :type edge_percents: dict
+    :rtype: dict
     :return: - geom_split : newly created vertices and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -110,8 +113,8 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
 
 def bisect_plane(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
+        Union[typing.List['bmesh.types.BMVert'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']],
         dist: float, plane_co: typing.List['mathutils.Vector'],
         plane_no: typing.List['mathutils.Vector'], use_snap_center: bool,
         clear_outer: bool, clear_inner: bool) -> dict:
@@ -120,7 +123,7 @@ def bisect_plane(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param dist: minimum distance when testing if a vert is exactly on the plane
     :type dist: float
     :param plane_co: point on the plane
@@ -133,6 +136,7 @@ def bisect_plane(
     :type clear_outer: bool
     :param clear_inner: when enabled. remove all geometry on the negative side of the plane
     :type clear_inner: bool
+    :rtype: dict
     :return: - geom_cut : output geometry aligned with the plane (new and existing) **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge ) - geom : input and output geometry (result of cut) **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -176,6 +180,7 @@ def bridge_loops(bm: 'bmesh.types.BMesh',
     :type merge_factor: float
     :param twist_offset: Undocumented.
     :type twist_offset: int
+    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace ) - edges : new edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -224,6 +229,7 @@ def connect_vert_pair(
     :type verts_exclude: typing.List['bmesh.types.BMVert']
     :param faces_exclude: Undocumented.
     :type faces_exclude: typing.List['bmesh.types.BMFace']
+    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -244,6 +250,7 @@ def connect_verts(bm: 'bmesh.types.BMesh',
     :type faces_exclude: typing.List['bmesh.types.BMFace']
     :param check_degenerate: prevent splits with overlaps & intersections
     :type check_degenerate: bool
+    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -258,6 +265,7 @@ def connect_verts_concave(bm: 'bmesh.types.BMesh',
     :type bm: 'bmesh.types.BMesh'
     :param faces: Undocumented.
     :type faces: typing.List['bmesh.types.BMFace']
+    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -274,6 +282,7 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
     :type angle_limit: float
     :param faces: Undocumented.
     :type faces: typing.List['bmesh.types.BMFace']
+    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -282,19 +291,20 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
 
 def contextual_create(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
+        Union[typing.List['bmesh.types.BMVert'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']],
         mat_nr: int, use_smooth: bool) -> dict:
     ''' Contextual Create. This is basically F-key, it creates new faces from vertices, makes stuff from edge nets, makes wire edges, etc. It also dissolves faces. Three verts become a triangle, four become a quad. Two become a wire edge.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param mat_nr: material to use
     :type mat_nr: int
     :param use_smooth: smooth to use
     :type use_smooth: bool
+    :rtype: dict
     :return: - faces : newly-made face(s) **type** list of ( bmesh.types.BMFace ) - edges : newly-made edge(s) **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -302,8 +312,8 @@ def contextual_create(
 
 
 def convex_hull(bm: 'bmesh.types.BMesh',
-                input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                    List['bmesh.types.BMVert'], typing.
+                input: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                                    List['bmesh.types.BMEdge'], typing.
                                     List['bmesh.types.BMFace']],
                 use_existing_faces: bool) -> dict:
     ''' Convex Hull Builds a convex hull from the vertices in 'input'. If 'use_existing_faces' is true, the hull will not output triangles that are covered by a pre-existing face. All hull vertices, faces, and edges are added to 'geom.out'. Any input elements that end up inside the hull (i.e. are not used by an output face) are added to the 'interior_geom' slot. The 'unused_geom' slot will contain all interior geometry that is completely unused. Lastly, 'holes_geom' contains edges and faces that were in the input and are part of the hull.
@@ -311,9 +321,10 @@ def convex_hull(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type input: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param use_existing_faces: Undocumented.
     :type use_existing_faces: bool
+    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_interior : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_unused : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_holes : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -339,6 +350,7 @@ def create_circle(bm: 'bmesh.types.BMesh', cap_ends: bool, cap_tris: bool,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -369,6 +381,7 @@ def create_cone(bm: 'bmesh.types.BMesh', cap_ends: bool, cap_tris: bool,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -387,6 +400,7 @@ def create_cube(bm: 'bmesh.types.BMesh', size: float,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -410,6 +424,7 @@ def create_grid(bm: 'bmesh.types.BMesh', x_segments: int, y_segments: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -431,6 +446,7 @@ def create_icosphere(bm: 'bmesh.types.BMesh', subdivisions: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -447,6 +463,7 @@ def create_monkey(bm: 'bmesh.types.BMesh', matrix: 'mathutils.Matrix',
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -470,6 +487,7 @@ def create_uvsphere(bm: 'bmesh.types.BMesh', u_segments: int, v_segments: int,
     :type matrix: 'mathutils.Matrix'
     :param calc_uvs: calculate default UVs
     :type calc_uvs: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -484,6 +502,7 @@ def create_vert(bm: 'bmesh.types.BMesh',
     :type bm: 'bmesh.types.BMesh'
     :param co: the coordinate of the new vert
     :type co: typing.List['mathutils.Vector']
+    :rtype: dict
     :return: - vert : the new vert **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -491,15 +510,15 @@ def create_vert(bm: 'bmesh.types.BMesh',
 
 
 def delete(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMVert'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                              List['bmesh.types.BMEdge'], typing.
                               List['bmesh.types.BMFace']], context: int):
     ''' Delete Geometry. Utility operator to delete geometry.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param context: enum DEL_VERTS ...
     :type context: int
     '''
@@ -535,6 +554,7 @@ def dissolve_edges(bm: 'bmesh.types.BMesh',
     :type use_verts: bool
     :param use_face_split: Undocumented.
     :type use_face_split: bool
+    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -552,6 +572,7 @@ def dissolve_faces(bm: 'bmesh.types.BMesh',
     :type faces: typing.List['bmesh.types.BMFace']
     :param use_verts: dissolve verts left between only 2 edges.
     :type use_verts: bool
+    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -577,6 +598,7 @@ def dissolve_limit(bm: 'bmesh.types.BMesh', angle_limit: float,
     :type edges: typing.List['bmesh.types.BMEdge']
     :param delimit: Undocumented.
     :type delimit: int
+    :rtype: dict
     :return: - region : **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -602,8 +624,8 @@ def dissolve_verts(bm: 'bmesh.types.BMesh',
 
 
 def duplicate(bm: 'bmesh.types.BMesh',
-              geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                 List['bmesh.types.BMVert'], typing.
+              geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                                 List['bmesh.types.BMEdge'], typing.
                                  List['bmesh.types.BMFace']],
               dest: 'bmesh.types.BMesh', use_select_history: bool) -> dict:
     ''' Duplicate Geometry. Utility operator to duplicate geometry, optionally into a destination mesh.
@@ -611,11 +633,12 @@ def duplicate(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_select_history: Undocumented.
     :type use_select_history: bool
+    :rtype: dict
     :return: - geom_orig : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - vert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - edge_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - face_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - boundary_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - isovert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -635,6 +658,7 @@ def edgeloop_fill(bm: 'bmesh.types.BMesh',
     :type mat_nr: int
     :param use_smooth: smooth state to use
     :type use_smooth: bool
+    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -656,6 +680,7 @@ def edgenet_fill(bm: 'bmesh.types.BMesh',
     :type use_smooth: bool
     :param sides: number of sides
     :type sides: int
+    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -670,6 +695,7 @@ def edgenet_prepare(bm: 'bmesh.types.BMesh',
     :type bm: 'bmesh.types.BMesh'
     :param edges: input edges
     :type edges: typing.List['bmesh.types.BMEdge']
+    :rtype: dict
     :return: - edges : new edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -687,6 +713,7 @@ def extrude_discrete_faces(bm: 'bmesh.types.BMesh',
     :type faces: typing.List['bmesh.types.BMFace']
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -704,6 +731,7 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
+    :rtype: dict
     :return: - geom : output geometry **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -712,8 +740,8 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
 
 def extrude_face_region(
         bm: 'bmesh.types.BMesh',
-        geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                           List['bmesh.types.BMVert'], typing.
+        geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                           List['bmesh.types.BMEdge'], typing.
                            List['bmesh.types.BMFace']], edges_exclude: set,
         use_keep_orig: bool, use_select_history: bool) -> dict:
     ''' Extrude Faces. Extrude operator (does not transform)
@@ -721,13 +749,14 @@ def extrude_face_region(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: edges and faces
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param edges_exclude: Undocumented.
     :type edges_exclude: set
     :param use_keep_orig: keep original geometry (requires geom to include edges).
     :type use_keep_orig: bool
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
+    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -745,6 +774,7 @@ def extrude_vert_indiv(bm: 'bmesh.types.BMesh',
     :type verts: typing.List['bmesh.types.BMVert']
     :param use_select_history: pass to duplicate
     :type use_select_history: bool
+    :rtype: dict
     :return: - edges : output wire edges **type** list of ( bmesh.types.BMEdge ) - verts : output vertices **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -764,6 +794,7 @@ def face_attribute_fill(bm: 'bmesh.types.BMesh',
     :type use_normals: bool
     :param use_data: copy face data
     :type use_data: bool
+    :rtype: dict
     :return: - faces_fail : faces that could not be handled **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -783,6 +814,7 @@ def find_doubles(
     :type keep_verts: typing.List['bmesh.types.BMVert']
     :param dist: minimum distance
     :type dist: float
+    :rtype: dict
     :return: - targetmap : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -804,6 +836,7 @@ def grid_fill(bm: 'bmesh.types.BMesh',
     :type use_smooth: bool
     :param use_interp_simple: use simple interpolation
     :type use_interp_simple: bool
+    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -820,6 +853,7 @@ def holes_fill(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param sides: number of face sides to fill
     :type sides: int
+    :rtype: dict
     :return: - faces : new faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -846,6 +880,7 @@ def inset_individual(bm: 'bmesh.types.BMesh',
     :type use_interpolate: bool
     :param use_relative_offset: Undocumented.
     :type use_relative_offset: bool
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -882,6 +917,7 @@ def inset_region(
     :type depth: float
     :param use_outset: Undocumented.
     :type use_outset: bool
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -913,6 +949,7 @@ def join_triangles(bm: 'bmesh.types.BMesh',
     :type angle_face_threshold: float
     :param angle_shape_threshold: Undocumented.
     :type angle_shape_threshold: float
+    :rtype: dict
     :return: - faces : joined faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -937,8 +974,8 @@ def mesh_to_bmesh(bm: 'bmesh.types.BMesh', mesh: 'bpy.types.Mesh',
 
 
 def mirror(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMVert'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                              List['bmesh.types.BMEdge'], typing.
                               List['bmesh.types.BMFace']],
            matrix: 'mathutils.Matrix', merge_dist: float, axis: int,
            mirror_u: bool, mirror_v: bool) -> dict:
@@ -947,7 +984,7 @@ def mirror(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param matrix: matrix defining the mirror transformation
     :type matrix: 'mathutils.Matrix'
     :param merge_dist: maximum distance for merging. does no merging if 0.
@@ -958,6 +995,7 @@ def mirror(bm: 'bmesh.types.BMesh',
     :type mirror_u: bool
     :param mirror_v: mirror UVs across the v axis
     :type mirror_v: bool
+    :rtype: dict
     :return: - geom : output geometry, mirrored **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -990,6 +1028,7 @@ def offset_edgeloops(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param use_cap_endpoint: Undocumented.
     :type use_cap_endpoint: bool
+    :rtype: dict
     :return: - edges : output faces **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1009,6 +1048,7 @@ def planar_faces(bm: 'bmesh.types.BMesh',
     :type iterations: int
     :param factor: Influence for making planar each iteration
     :type factor: float
+    :rtype: dict
     :return: - geom : output slot, computed boundary geometry. **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1061,6 +1101,7 @@ def poke(bm: 'bmesh.types.BMesh', faces: typing.List['bmesh.types.BMFace'],
     :type center_mode: int
     :param use_relative_offset: apply offset
     :type use_relative_offset: bool
+    :rtype: dict
     :return: - verts : output verts **type** list of ( bmesh.types.BMVert ) - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1082,21 +1123,22 @@ def recalc_face_normals(bm: 'bmesh.types.BMesh',
 
 def region_extend(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
+        Union[typing.List['bmesh.types.BMVert'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']],
         use_contract: bool, use_faces: bool, use_face_step: bool) -> dict:
     ''' Region Extend. used to implement the select more/less tools. this puts some geometry surrounding regions of geometry in geom into geom.out. if use_faces is 0 then geom.out spits out verts and edges, otherwise it spits out faces.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param use_contract: find boundary inside the regions, not outside.
     :type use_contract: bool
     :param use_faces: extend from faces instead of edges
     :type use_faces: bool
     :param use_face_step: step over connected faces
     :type use_face_step: bool
+    :rtype: dict
     :return: - geom : output slot, computed boundary geometry. **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1207,6 +1249,7 @@ def rotate_edges(bm: 'bmesh.types.BMesh',
     :type edges: typing.List['bmesh.types.BMEdge']
     :param use_ccw: rotate edge counter-clockwise if true, otherwise clockwise
     :type use_ccw: bool
+    :rtype: dict
     :return: - edges : newly spun edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1260,6 +1303,7 @@ def similar_edges(bm: 'bmesh.types.BMesh',
     :type thresh: float
     :param compare: comparison method
     :type compare: int
+    :rtype: dict
     :return: - edges : output edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1281,6 +1325,7 @@ def similar_faces(bm: 'bmesh.types.BMesh',
     :type thresh: float
     :param compare: comparison method
     :type compare: int
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1302,6 +1347,7 @@ def similar_verts(bm: 'bmesh.types.BMesh',
     :type thresh: float
     :param compare: comparison method
     :type compare: int
+    :rtype: dict
     :return: - verts : output vertices **type** list of ( bmesh.types.BMVert )
     '''
 
@@ -1368,8 +1414,8 @@ def smooth_vert(bm: 'bmesh.types.BMesh',
 
 
 def solidify(bm: 'bmesh.types.BMesh',
-             geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                List['bmesh.types.BMVert'], typing.
+             geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                                List['bmesh.types.BMEdge'], typing.
                                 List['bmesh.types.BMFace']],
              thickness: float) -> dict:
     ''' Solidify. Turns a mesh into a shell with thickness
@@ -1377,9 +1423,10 @@ def solidify(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param thickness: Undocumented.
     :type thickness: float
+    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1387,8 +1434,8 @@ def solidify(bm: 'bmesh.types.BMesh',
 
 
 def spin(bm: 'bmesh.types.BMesh', geom: typing.
-         Union[typing.List['bmesh.types.BMEdge'], typing.
-               List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
+         Union[typing.List['bmesh.types.BMVert'], typing.
+               List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']],
          cent: typing.List['mathutils.Vector'],
          axis: typing.List['mathutils.Vector'],
          dvec: typing.List['mathutils.Vector'], angle: float,
@@ -1398,7 +1445,7 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param cent: rotation center
     :type cent: typing.List['mathutils.Vector']
     :param axis: rotation axis
@@ -1413,6 +1460,7 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :type steps: int
     :param use_duplicate: duplicate or extrude?
     :type use_duplicate: bool
+    :rtype: dict
     :return: - geom_last : result of last step **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1420,19 +1468,20 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
 
 
 def split(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMEdge'], typing.
-                List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']],
+          Union[typing.List['bmesh.types.BMVert'], typing.
+                List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']],
           dest: 'bmesh.types.BMesh', use_only_faces: bool) -> dict:
     ''' Split Off Geometry. Disconnect geometry from adjacent edges and faces, optionally into a destination mesh.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_only_faces: when enabled. don't duplicate loose verts/edges
     :type use_only_faces: bool
+    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - boundary_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - isovert_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -1452,6 +1501,7 @@ def split_edges(
     :type verts: typing.List['bmesh.types.BMVert']
     :param use_verts: use 'verts' for splitting, else just find verts to split from edges
     :type use_verts: bool
+    :rtype: dict
     :return: - edges : old output disconnected edges **type** list of ( bmesh.types.BMEdge )
     '''
 
@@ -1478,6 +1528,7 @@ def subdivide_edgering(
     :type profile_shape: int
     :param profile_shape_factor: Undocumented.
     :type profile_shape_factor: float
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
@@ -1525,6 +1576,7 @@ def subdivide_edges(
     :type use_sphere: bool
     :param use_smooth_even: maintain even offset when smoothing
     :type use_smooth_even: bool
+    :rtype: dict
     :return: - geom_inner : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_split : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom : contains all output geometry **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1532,8 +1584,8 @@ def subdivide_edges(
 
 
 def symmetrize(bm: 'bmesh.types.BMesh',
-               input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                   List['bmesh.types.BMVert'], typing.
+               input: typing.Union[typing.List['bmesh.types.BMVert'], typing.
+                                   List['bmesh.types.BMEdge'], typing.
                                    List['bmesh.types.BMFace']], direction: int,
                dist: float) -> dict:
     ''' Symmetrize. Makes the mesh elements in the "input" slot symmetrical. Unlike normal mirroring, it only copies in one direction, as specified by the "direction" slot. The edges and faces that cross the plane of symmetry are split as needed to enforce symmetry. All new vertices, edges, and faces are added to the "geom.out" slot.
@@ -1541,11 +1593,12 @@ def symmetrize(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMFace']]
+    :type input: typing.Union[typing.List['bmesh.types.BMVert'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace']]
     :param direction: Undocumented.
     :type direction: int
     :param dist: minimum distance
     :type dist: float
+    :rtype: dict
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1603,6 +1656,7 @@ def triangle_fill(bm: 'bmesh.types.BMesh', use_beauty: bool,
     :type edges: typing.List['bmesh.types.BMEdge']
     :param normal: optionally pass the fill normal to use
     :type normal: typing.List['mathutils.Vector']
+    :rtype: dict
     :return: - geom : new faces and edges **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
     '''
 
@@ -1622,6 +1676,7 @@ def triangulate(bm: 'bmesh.types.BMesh',
     :type quad_method: int
     :param ngon_method: Undocumented.
     :type ngon_method: int
+    :rtype: dict
     :return: - edges : **type** list of ( bmesh.types.BMEdge ) - faces : **type** list of ( bmesh.types.BMFace ) - face_map : **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace - face_map_double : duplicate faces **type** dict mapping vert/edge/face types to bmesh.types.BMVert / bmesh.types.BMEdge / bmesh.types.BMFace
     '''
 
@@ -1685,6 +1740,7 @@ def wireframe(bm: 'bmesh.types.BMesh',
     :type use_relative_offset: bool
     :param material_offset: Undocumented.
     :type material_offset: int
+    :rtype: dict
     :return: - faces : output faces **type** list of ( bmesh.types.BMFace )
     '''
 
