@@ -11,6 +11,7 @@ def edge_rotate(edge: 'bmesh.types.BMEdge',
     :type edge: 'bmesh.types.BMEdge'
     :param ccw: When True the edge will be rotated counter clockwise.
     :type ccw: bool
+    :rtype: 'bmesh.types.BMEdge'
     :return: The newly rotated edge.
     '''
 
@@ -27,6 +28,7 @@ def edge_split(edge: 'bmesh.types.BMEdge', vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param fac: The point on the edge where the new vert will be created [0 - 1].
     :type fac: float
+    :rtype: tuple
     :return: The newly created (edge, vert) pair.
     '''
 
@@ -51,6 +53,7 @@ def face_join(faces: 'bmesh.types.BMFace',
     :type faces: 'bmesh.types.BMFace'
     :param remove: Remove the edges and vertices between the faces.
     :type remove: bool
+    :rtype: 'bmesh.types.BMFace'
     :return: The newly created face or None on failure.
     '''
 
@@ -77,6 +80,7 @@ def face_split(face: 'bmesh.types.BMFace',
     :type use_exist: bool
     :param example: Newly created edge will copy settings from this one.
     :type example: 'bmesh.types.BMEdge'
+    :rtype: 'bmesh.types.BMLoop'
     :return: The newly created face or None on failure.
     '''
 
@@ -93,6 +97,7 @@ def face_split_edgenet(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param edgenet: Sequence of edges.
     :type edgenet: 'bmesh.types.BMEdge'
+    :rtype: 'bmesh.types.BMFace'
     :return: The newly created faces.
     '''
 
@@ -107,6 +112,7 @@ def face_vert_separate(face: 'bmesh.types.BMFace',
     :type face: 'bmesh.types.BMFace'
     :param vert: A vertex in the face to separate.
     :type vert: 'bmesh.types.BMVert'
+    :rtype: 'bmesh.types.BMVert'
     :return: The newly created vertex or None on failure.
     '''
 
@@ -118,6 +124,7 @@ def loop_separate(loop: 'bmesh.types.BMLoop') -> 'bmesh.types.BMVert':
 
     :param loop: The loop to separate.
     :type loop: 'bmesh.types.BMLoop'
+    :rtype: 'bmesh.types.BMVert'
     :return: The newly created vertex or None on failure.
     '''
 
@@ -132,6 +139,7 @@ def vert_collapse_edge(vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param edge: The edge to collapse into.
     :type edge: 'bmesh.types.BMEdge'
+    :rtype: 'bmesh.types.BMEdge'
     :return: The resulting edge from the collapse operation.
     '''
 
@@ -148,6 +156,7 @@ def vert_collapse_faces(vert: 'bmesh.types.BMVert', edge: 'bmesh.types.BMEdge',
     :type edge: 'bmesh.types.BMEdge'
     :param fac: The factor to use when merging customdata [0 - 1].
     :type fac: float
+    :rtype: 'bmesh.types.BMEdge'
     :return: The resulting edge from the collapse operation.
     '''
 
@@ -159,6 +168,7 @@ def vert_dissolve(vert: 'bmesh.types.BMVert') -> bool:
 
     :param vert: The vert to be dissolved.
     :type vert: 'bmesh.types.BMVert'
+    :rtype: bool
     :return: True when the vertex dissolve is successful.
     '''
 
@@ -173,6 +183,7 @@ def vert_separate(vert: 'bmesh.types.BMVert',
     :type vert: 'bmesh.types.BMVert'
     :param edges: The edges to separated.
     :type edges: 'bmesh.types.BMEdge'
+    :rtype: 'bmesh.types.BMVert'
     :return: The newly separated verts (including the vertex passed).
     '''
 
