@@ -3,8 +3,8 @@ import typing
 
 
 def autodesk_3ds(filepath: str = "",
-                 axis_forward: typing.Union[int, str] = 'Y',
-                 axis_up: typing.Union[int, str] = 'Z',
+                 axis_forward: typing.Union[str, int] = 'Y',
+                 axis_up: typing.Union[str, int] = 'Z',
                  filter_glob: str = "*.3ds",
                  constrain_size: float = 10.0,
                  use_image_search: bool = True,
@@ -14,9 +14,9 @@ def autodesk_3ds(filepath: str = "",
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param constrain_size: Size Constraint, Scale the model by 10 until it reaches the size constraint (0 to disable)
@@ -31,11 +31,11 @@ def autodesk_3ds(filepath: str = "",
 
 
 def fbx(filepath: str = "",
-        axis_forward: typing.Union[int, str] = '-Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = '-Z',
+        axis_up: typing.Union[str, int] = 'Y',
         directory: str = "",
         filter_glob: str = "*.fbx",
-        ui_tab: typing.Union[int, str] = 'MAIN',
+        ui_tab: typing.Union[str, int] = 'MAIN',
         use_manual_orientation: bool = False,
         global_scale: float = 1.0,
         bake_space_transform: bool = False,
@@ -50,23 +50,23 @@ def fbx(filepath: str = "",
         ignore_leaf_bones: bool = False,
         force_connect_children: bool = False,
         automatic_bone_orientation: bool = False,
-        primary_bone_axis: typing.Union[int, str] = 'Y',
-        secondary_bone_axis: typing.Union[int, str] = 'X',
+        primary_bone_axis: typing.Union[str, int] = 'Y',
+        secondary_bone_axis: typing.Union[str, int] = 'X',
         use_prepost_rot: bool = True):
     ''' Load a FBX file
 
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param directory: directory
     :type directory: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param ui_tab: ui_tab, Import options categories * MAIN Main, Main basic settings. * ARMATURE Armatures, Armature-related settings.
-    :type ui_tab: typing.Union[int, str]
+    :type ui_tab: typing.Union[str, int]
     :param use_manual_orientation: Manual Orientation, Specify orientation and scale, instead of using embedded data in FBX file
     :type use_manual_orientation: bool
     :param global_scale: Scale
@@ -96,9 +96,9 @@ def fbx(filepath: str = "",
     :param automatic_bone_orientation: Automatic Bone Orientation, Try to align the major bone axis with the bone children
     :type automatic_bone_orientation: bool
     :param primary_bone_axis: Primary Bone Axis
-    :type primary_bone_axis: typing.Union[int, str]
+    :type primary_bone_axis: typing.Union[str, int]
     :param secondary_bone_axis: Secondary Bone Axis
-    :type secondary_bone_axis: typing.Union[int, str]
+    :type secondary_bone_axis: typing.Union[str, int]
     :param use_prepost_rot: Use Pre/Post Rotation, Use pre/post rotation from FBX transform (you may have to disable that in some cases)
     :type use_prepost_rot: bool
     '''
@@ -107,8 +107,8 @@ def fbx(filepath: str = "",
 
 
 def obj(filepath: str = "",
-        axis_forward: typing.Union[int, str] = '-Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = '-Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.obj;*.mtl",
         use_edges: bool = True,
         use_smooth_groups: bool = True,
@@ -116,16 +116,16 @@ def obj(filepath: str = "",
         use_split_groups: bool = True,
         use_groups_as_vgroups: bool = False,
         use_image_search: bool = True,
-        split_mode: typing.Union[int, str] = 'ON',
+        split_mode: typing.Union[str, int] = 'ON',
         global_clamp_size: float = 0.0):
     ''' Load a Wavefront OBJ File
 
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_edges: Lines, Import lines and faces with 2 verts as edge
@@ -141,7 +141,7 @@ def obj(filepath: str = "",
     :param use_image_search: Image Search, Search subdirs for any associated images (Warning, may be slow)
     :type use_image_search: bool
     :param split_mode: Split * ON Split, Split geometry, omits unused verts. * OFF Keep Vert Order, Keep vertex order from file.
-    :type split_mode: typing.Union[int, str]
+    :type split_mode: typing.Union[str, int]
     :param global_clamp_size: Clamp Size, Clamp bounds under this value (zero to disable)
     :type global_clamp_size: float
     '''
@@ -150,17 +150,17 @@ def obj(filepath: str = "",
 
 
 def x3d(filepath: str = "",
-        axis_forward: typing.Union[int, str] = 'Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = 'Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.x3d;*.wrl"):
     ''' Import an X3D or VRML2 file
 
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     '''
