@@ -11,18 +11,18 @@ def add_simple_uvs():
     pass
 
 
-def add_texture_paint_slot(type: typing.Union[int, str] = 'DIFFUSE_COLOR',
+def add_texture_paint_slot(type: typing.Union[str, int] = 'DIFFUSE_COLOR',
                            name: str = "Untitled",
                            width: int = 1024,
                            height: int = 1024,
                            color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
                            alpha: bool = True,
-                           generated_type: typing.Union[int, str] = 'BLANK',
+                           generated_type: typing.Union[str, int] = 'BLANK',
                            float: bool = False):
     ''' Add a texture paint slot
 
     :param type: Type, Merge method to use
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param name: Name, Image data-block name
     :type name: str
     :param width: Width, Image width
@@ -34,7 +34,7 @@ def add_texture_paint_slot(type: typing.Union[int, str] = 'DIFFUSE_COLOR',
     :param alpha: Alpha, Create an image with an alpha channel
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[int, str]
+    :type generated_type: typing.Union[str, int]
     :param float: 32 bit Float, Create image with 32 bit floating point bit depth
     :type float: bool
     '''
@@ -50,25 +50,25 @@ def brush_colors_flip():
     pass
 
 
-def brush_select(paint_mode: typing.Union[int, str] = 'ACTIVE',
-                 sculpt_tool: typing.Union[int, str] = 'BLOB',
-                 vertex_paint_tool: typing.Union[int, str] = 'MIX',
-                 weight_paint_tool: typing.Union[int, str] = 'MIX',
-                 texture_paint_tool: typing.Union[int, str] = 'DRAW',
+def brush_select(paint_mode: typing.Union[str, int] = 'ACTIVE',
+                 sculpt_tool: typing.Union[str, int] = 'BLOB',
+                 vertex_paint_tool: typing.Union[str, int] = 'MIX',
+                 weight_paint_tool: typing.Union[str, int] = 'MIX',
+                 texture_paint_tool: typing.Union[str, int] = 'DRAW',
                  toggle: bool = False,
                  create_missing: bool = False):
     ''' Select a paint mode's brush by tool type
 
     :param paint_mode: Paint Mode * ACTIVE Current, Set brush for active paint mode. * SCULPT Sculpt. * VERTEX_PAINT Vertex Paint. * WEIGHT_PAINT Weight Paint. * TEXTURE_PAINT Texture Paint.
-    :type paint_mode: typing.Union[int, str]
+    :type paint_mode: typing.Union[str, int]
     :param sculpt_tool: Sculpt Tool
-    :type sculpt_tool: typing.Union[int, str]
+    :type sculpt_tool: typing.Union[str, int]
     :param vertex_paint_tool: Vertex Paint Tool * MIX Mix, Use mix blending mode while painting. * ADD Add, Use add blending mode while painting. * SUB Subtract, Use subtract blending mode while painting. * MUL Multiply, Use multiply blending mode while painting. * BLUR Blur, Blur the color with surrounding values. * LIGHTEN Lighten, Use lighten blending mode while painting. * DARKEN Darken, Use darken blending mode while painting.
-    :type vertex_paint_tool: typing.Union[int, str]
+    :type vertex_paint_tool: typing.Union[str, int]
     :param weight_paint_tool: Weight Paint Tool * MIX Mix, Use mix blending mode while painting. * ADD Add, Use add blending mode while painting. * SUB Subtract, Use subtract blending mode while painting. * MUL Multiply, Use multiply blending mode while painting. * BLUR Blur, Blur the color with surrounding values. * LIGHTEN Lighten, Use lighten blending mode while painting. * DARKEN Darken, Use darken blending mode while painting.
-    :type weight_paint_tool: typing.Union[int, str]
+    :type weight_paint_tool: typing.Union[str, int]
     :param texture_paint_tool: Texture Paint Tool
-    :type texture_paint_tool: typing.Union[int, str]
+    :type texture_paint_tool: typing.Union[str, int]
     :param toggle: Toggle, Toggle between two brushes rather than cycling
     :type toggle: bool
     :param create_missing: Create Missing, If the requested brush type does not exist, create a new brush
@@ -86,11 +86,11 @@ def delete_texture_paint_slot():
     pass
 
 
-def face_select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def face_select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection for all faces
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -144,8 +144,8 @@ def grab_clone(delta: typing.List[float] = (0.0, 0.0)):
     pass
 
 
-def hide_show(action: typing.Union[int, str] = 'HIDE',
-              area: typing.Union[int, str] = 'INSIDE',
+def hide_show(action: typing.Union[str, int] = 'HIDE',
+              area: typing.Union[str, int] = 'INSIDE',
               xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
@@ -153,9 +153,9 @@ def hide_show(action: typing.Union[int, str] = 'HIDE',
     ''' Hide/show some vertices
 
     :param action: Action, Whether to hide or show vertices * HIDE Hide, Hide vertices. * SHOW Show, Show vertices.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     :param area: Area, Which vertices to hide or show * OUTSIDE Outside, Hide or show vertices outside the selection. * INSIDE Inside, Hide or show vertices inside the selection. * ALL All, Hide or show all vertices. * MASKED Masked, Hide or show vertices that are masked (minimum mask value of 0.5).
-    :type area: typing.Union[int, str]
+    :type area: typing.Union[str, int]
     :param xmin: X Min
     :type xmin: int
     :param xmax: X Max
@@ -182,24 +182,24 @@ def image_from_view(filepath: str = ""):
 def image_paint(stroke: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
         List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                mode: typing.Union[int, str] = 'NORMAL'):
+                mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke into the image
 
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
 
 
-def mask_flood_fill(mode: typing.Union[int, str] = 'VALUE',
+def mask_flood_fill(mode: typing.Union[str, int] = 'VALUE',
                     value: float = 0.0):
     ''' Fill the whole mask with a given value, or invert its values
 
     :param mode: Mode * VALUE Value, Set mask to the level specified by the 'value' property. * VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted 'value' property. * INVERT Invert, Invert the mask.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
     :type value: float
     '''
@@ -210,14 +210,14 @@ def mask_flood_fill(mode: typing.Union[int, str] = 'VALUE',
 def mask_lasso_gesture(path: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
         List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
-                       mode: typing.Union[int, str] = 'VALUE',
+                       mode: typing.Union[str, int] = 'VALUE',
                        value: float = 1.0):
     ''' Add mask within the lasso as you move the brush
 
     :param path: path
     :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * VALUE Value, Set mask to the level specified by the 'value' property. * VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted 'value' property. * INVERT Invert, Invert the mask.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param value: Value, Mask level to use when mode is 'Value'; zero means no masking and one is fully masked
     :type value: float
     '''
@@ -225,11 +225,11 @@ def mask_lasso_gesture(path: typing.Union[
     pass
 
 
-def project_image(image: typing.Union[int, str] = ''):
+def project_image(image: typing.Union[str, int] = ''):
     ''' Project an edited render from the active camera back onto the object
 
     :param image: Image
-    :type image: typing.Union[int, str]
+    :type image: typing.Union[str, int]
     '''
 
     pass
@@ -259,11 +259,11 @@ def texture_paint_toggle():
     pass
 
 
-def vert_select_all(action: typing.Union[int, str] = 'TOGGLE'):
+def vert_select_all(action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection for all vertices
 
     :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
-    :type action: typing.Union[int, str]
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -367,13 +367,13 @@ def vertex_color_smooth():
 def vertex_paint(stroke: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
         List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'NORMAL'):
+                 mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke in the active vertex color layer
 
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -387,17 +387,17 @@ def vertex_paint_toggle():
     pass
 
 
-def weight_from_bones(type: typing.Union[int, str] = 'AUTOMATIC'):
+def weight_from_bones(type: typing.Union[str, int] = 'AUTOMATIC'):
     ''' Set the weights of the groups matching the attached armature's selected bones, using the distance between the vertices and the bones
 
     :param type: Type, Method to use for assigning weights * AUTOMATIC Automatic, Automatic weights from bones. * ENVELOPES From Envelopes, Weights from envelopes with user defined radius.
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     '''
 
     pass
 
 
-def weight_gradient(type: typing.Union[int, str] = 'LINEAR',
+def weight_gradient(type: typing.Union[str, int] = 'LINEAR',
                     xstart: int = 0,
                     xend: int = 0,
                     ystart: int = 0,
@@ -406,7 +406,7 @@ def weight_gradient(type: typing.Union[int, str] = 'LINEAR',
     ''' Draw a line to apply a weight gradient to selected vertices
 
     :param type: Type
-    :type type: typing.Union[int, str]
+    :type type: typing.Union[str, int]
     :param xstart: X Start
     :type xstart: int
     :param xend: X End
@@ -425,13 +425,13 @@ def weight_gradient(type: typing.Union[int, str] = 'LINEAR',
 def weight_paint(stroke: typing.Union[
         typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
         List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                 mode: typing.Union[int, str] = 'NORMAL'):
+                 mode: typing.Union[str, int] = 'NORMAL'):
     ''' Paint a stroke in the current vertex group's weights
 
     :param stroke: Stroke
     :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param mode: Stroke Mode, Action taken when a paint stroke is made * NORMAL Normal, Apply brush normally. * INVERT Invert, Invert action of brush for duration of stroke. * SMOOTH Smooth, Switch brush to smooth mode for duration of stroke.
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     '''
 
     pass
@@ -453,11 +453,11 @@ def weight_sample():
     pass
 
 
-def weight_sample_group(group: typing.Union[int, str] = 'DEFAULT'):
+def weight_sample_group(group: typing.Union[str, int] = 'DEFAULT'):
     ''' Select one of the vertex groups available under current mouse position
 
     :param group: Keying Set, The Keying Set to use
-    :type group: typing.Union[int, str]
+    :type group: typing.Union[str, int]
     '''
 
     pass
