@@ -4,11 +4,11 @@ import typing
 
 def bend(value: typing.List[float] = (0.0),
          mirror: bool = False,
-         proportional: typing.Union[int, str] = 'DISABLED',
-         proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+         proportional: typing.Union[str, int] = 'DISABLED',
+         proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
          proportional_size: float = 1.0,
          snap: bool = False,
-         snap_target: typing.Union[int, str] = 'CLOSEST',
+         snap_target: typing.Union[str, int] = 'CLOSEST',
          snap_point: typing.List[float] = (0.0, 0.0, 0.0),
          snap_align: bool = False,
          snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -22,15 +22,15 @@ def bend(value: typing.List[float] = (0.0),
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -77,7 +77,7 @@ def delete_orientation():
 
 def edge_bevelweight(value: float = 0.0,
                      snap: bool = False,
-                     snap_target: typing.Union[int, str] = 'CLOSEST',
+                     snap_target: typing.Union[str, int] = 'CLOSEST',
                      snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                      snap_align: bool = False,
                      snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -90,7 +90,7 @@ def edge_bevelweight(value: float = 0.0,
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -108,7 +108,7 @@ def edge_bevelweight(value: float = 0.0,
 
 def edge_crease(value: float = 0.0,
                 snap: bool = False,
-                snap_target: typing.Union[int, str] = 'CLOSEST',
+                snap_target: typing.Union[str, int] = 'CLOSEST',
                 snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                 snap_align: bool = False,
                 snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -121,7 +121,7 @@ def edge_crease(value: float = 0.0,
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -144,7 +144,7 @@ def edge_slide(value: float = 0.0,
                use_clamp: bool = True,
                mirror: bool = False,
                snap: bool = False,
-               snap_target: typing.Union[int, str] = 'CLOSEST',
+               snap_target: typing.Union[str, int] = 'CLOSEST',
                snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                snap_align: bool = False,
                snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -168,7 +168,7 @@ def edge_slide(value: float = 0.0,
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -187,9 +187,9 @@ def edge_slide(value: float = 0.0,
 
 
 def mirror(constraint_axis: typing.List[bool] = (False, False, False),
-           constraint_orientation: typing.Union[int, str] = 'GLOBAL',
-           proportional: typing.Union[int, str] = 'DISABLED',
-           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+           constraint_orientation: typing.Union[str, int] = 'GLOBAL',
+           proportional: typing.Union[str, int] = 'DISABLED',
+           proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
            proportional_size: float = 1.0,
            gpencil_strokes: bool = False,
            release_confirm: bool = False,
@@ -199,11 +199,11 @@ def mirror(constraint_axis: typing.List[bool] = (False, False, False),
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
@@ -219,11 +219,11 @@ def mirror(constraint_axis: typing.List[bool] = (False, False, False),
 
 def push_pull(value: float = 0.0,
               mirror: bool = False,
-              proportional: typing.Union[int, str] = 'DISABLED',
-              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+              proportional: typing.Union[str, int] = 'DISABLED',
+              proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
               proportional_size: float = 1.0,
               snap: bool = False,
-              snap_target: typing.Union[int, str] = 'CLOSEST',
+              snap_target: typing.Union[str, int] = 'CLOSEST',
               snap_point: typing.List[float] = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -236,15 +236,15 @@ def push_pull(value: float = 0.0,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -262,13 +262,13 @@ def push_pull(value: float = 0.0,
 
 def resize(value: typing.List[float] = (1.0, 1.0, 1.0),
            constraint_axis: typing.List[bool] = (False, False, False),
-           constraint_orientation: typing.Union[int, str] = 'GLOBAL',
+           constraint_orientation: typing.Union[str, int] = 'GLOBAL',
            mirror: bool = False,
-           proportional: typing.Union[int, str] = 'DISABLED',
-           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+           proportional: typing.Union[str, int] = 'DISABLED',
+           proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
            proportional_size: float = 1.0,
            snap: bool = False,
-           snap_target: typing.Union[int, str] = 'CLOSEST',
+           snap_target: typing.Union[str, int] = 'CLOSEST',
            snap_point: typing.List[float] = (0.0, 0.0, 0.0),
            snap_align: bool = False,
            snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -284,19 +284,19 @@ def resize(value: typing.List[float] = (1.0, 1.0, 1.0),
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -321,13 +321,13 @@ def resize(value: typing.List[float] = (1.0, 1.0, 1.0),
 def rotate(value: float = 0.0,
            axis: typing.List[float] = (0.0, 0.0, 0.0),
            constraint_axis: typing.List[bool] = (False, False, False),
-           constraint_orientation: typing.Union[int, str] = 'GLOBAL',
+           constraint_orientation: typing.Union[str, int] = 'GLOBAL',
            mirror: bool = False,
-           proportional: typing.Union[int, str] = 'DISABLED',
-           proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+           proportional: typing.Union[str, int] = 'DISABLED',
+           proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
            proportional_size: float = 1.0,
            snap: bool = False,
-           snap_target: typing.Union[int, str] = 'CLOSEST',
+           snap_target: typing.Union[str, int] = 'CLOSEST',
            snap_point: typing.List[float] = (0.0, 0.0, 0.0),
            snap_align: bool = False,
            snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -343,19 +343,19 @@ def rotate(value: float = 0.0,
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -373,11 +373,11 @@ def rotate(value: float = 0.0,
     pass
 
 
-def select_orientation(orientation: typing.Union[int, str] = 'GLOBAL'):
+def select_orientation(orientation: typing.Union[str, int] = 'GLOBAL'):
     ''' Select transformation orientation
 
     :param orientation: Orientation, Transformation orientation
-    :type orientation: typing.Union[int, str]
+    :type orientation: typing.Union[str, int]
     '''
 
     pass
@@ -385,7 +385,7 @@ def select_orientation(orientation: typing.Union[int, str] = 'GLOBAL'):
 
 def seq_slide(value: typing.List[float] = (0.0, 0.0),
               snap: bool = False,
-              snap_target: typing.Union[int, str] = 'CLOSEST',
+              snap_target: typing.Union[str, int] = 'CLOSEST',
               snap_point: typing.List[float] = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -398,7 +398,7 @@ def seq_slide(value: typing.List[float] = (0.0, 0.0),
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -416,11 +416,11 @@ def seq_slide(value: typing.List[float] = (0.0, 0.0),
 
 def shear(value: float = 0.0,
           mirror: bool = False,
-          proportional: typing.Union[int, str] = 'DISABLED',
-          proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+          proportional: typing.Union[str, int] = 'DISABLED',
+          proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
           proportional_size: float = 1.0,
           snap: bool = False,
-          snap_target: typing.Union[int, str] = 'CLOSEST',
+          snap_target: typing.Union[str, int] = 'CLOSEST',
           snap_point: typing.List[float] = (0.0, 0.0, 0.0),
           snap_align: bool = False,
           snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -434,15 +434,15 @@ def shear(value: float = 0.0,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -463,11 +463,11 @@ def shear(value: float = 0.0,
 def shrink_fatten(value: float = 0.0,
                   use_even_offset: bool = True,
                   mirror: bool = False,
-                  proportional: typing.Union[int, str] = 'DISABLED',
-                  proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+                  proportional: typing.Union[str, int] = 'DISABLED',
+                  proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
                   proportional_size: float = 1.0,
                   snap: bool = False,
-                  snap_target: typing.Union[int, str] = 'CLOSEST',
+                  snap_target: typing.Union[str, int] = 'CLOSEST',
                   snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                   snap_align: bool = False,
                   snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -482,15 +482,15 @@ def shrink_fatten(value: float = 0.0,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -508,13 +508,13 @@ def shrink_fatten(value: float = 0.0,
 
 def skin_resize(value: typing.List[float] = (1.0, 1.0, 1.0),
                 constraint_axis: typing.List[bool] = (False, False, False),
-                constraint_orientation: typing.Union[int, str] = 'GLOBAL',
+                constraint_orientation: typing.Union[str, int] = 'GLOBAL',
                 mirror: bool = False,
-                proportional: typing.Union[int, str] = 'DISABLED',
-                proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+                proportional: typing.Union[str, int] = 'DISABLED',
+                proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
                 proportional_size: float = 1.0,
                 snap: bool = False,
-                snap_target: typing.Union[int, str] = 'CLOSEST',
+                snap_target: typing.Union[str, int] = 'CLOSEST',
                 snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                 snap_align: bool = False,
                 snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -527,19 +527,19 @@ def skin_resize(value: typing.List[float] = (1.0, 1.0, 1.0),
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -557,11 +557,11 @@ def skin_resize(value: typing.List[float] = (1.0, 1.0, 1.0),
 
 def tilt(value: float = 0.0,
          mirror: bool = False,
-         proportional: typing.Union[int, str] = 'DISABLED',
-         proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+         proportional: typing.Union[str, int] = 'DISABLED',
+         proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
          proportional_size: float = 1.0,
          snap: bool = False,
-         snap_target: typing.Union[int, str] = 'CLOSEST',
+         snap_target: typing.Union[str, int] = 'CLOSEST',
          snap_point: typing.List[float] = (0.0, 0.0, 0.0),
          snap_align: bool = False,
          snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -574,15 +574,15 @@ def tilt(value: float = 0.0,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -600,11 +600,11 @@ def tilt(value: float = 0.0,
 
 def tosphere(value: float = 0.0,
              mirror: bool = False,
-             proportional: typing.Union[int, str] = 'DISABLED',
-             proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+             proportional: typing.Union[str, int] = 'DISABLED',
+             proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
              proportional_size: float = 1.0,
              snap: bool = False,
-             snap_target: typing.Union[int, str] = 'CLOSEST',
+             snap_target: typing.Union[str, int] = 'CLOSEST',
              snap_point: typing.List[float] = (0.0, 0.0, 0.0),
              snap_align: bool = False,
              snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -618,15 +618,15 @@ def tosphere(value: float = 0.0,
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -646,11 +646,11 @@ def tosphere(value: float = 0.0,
 
 def trackball(value: typing.List[float] = (0.0, 0.0),
               mirror: bool = False,
-              proportional: typing.Union[int, str] = 'DISABLED',
-              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+              proportional: typing.Union[str, int] = 'DISABLED',
+              proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
               proportional_size: float = 1.0,
               snap: bool = False,
-              snap_target: typing.Union[int, str] = 'CLOSEST',
+              snap_target: typing.Union[str, int] = 'CLOSEST',
               snap_point: typing.List[float] = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -664,15 +664,15 @@ def trackball(value: typing.List[float] = (0.0, 0.0),
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -690,17 +690,17 @@ def trackball(value: typing.List[float] = (0.0, 0.0),
     pass
 
 
-def transform(mode: typing.Union[int, str] = 'TRANSLATION',
+def transform(mode: typing.Union[str, int] = 'TRANSLATION',
               value: typing.List[float] = (0.0, 0.0, 0.0, 0.0),
               axis: typing.List[float] = (0.0, 0.0, 0.0),
               constraint_axis: typing.List[bool] = (False, False, False),
-              constraint_orientation: typing.Union[int, str] = 'GLOBAL',
+              constraint_orientation: typing.Union[str, int] = 'GLOBAL',
               mirror: bool = False,
-              proportional: typing.Union[int, str] = 'DISABLED',
-              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+              proportional: typing.Union[str, int] = 'DISABLED',
+              proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
               proportional_size: float = 1.0,
               snap: bool = False,
-              snap_target: typing.Union[int, str] = 'CLOSEST',
+              snap_target: typing.Union[str, int] = 'CLOSEST',
               snap_point: typing.List[float] = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -710,7 +710,7 @@ def transform(mode: typing.Union[int, str] = 'TRANSLATION',
     ''' Transform selected items by mode type
 
     :param mode: Mode
-    :type mode: typing.Union[int, str]
+    :type mode: typing.Union[str, int]
     :param value: Values
     :type value: typing.List[float]
     :param axis: Axis, The axis around which the transformation occurs
@@ -718,19 +718,19 @@ def transform(mode: typing.Union[int, str] = 'TRANSLATION',
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -750,13 +750,13 @@ def transform(mode: typing.Union[int, str] = 'TRANSLATION',
 
 def translate(value: typing.List[float] = (0.0, 0.0, 0.0),
               constraint_axis: typing.List[bool] = (False, False, False),
-              constraint_orientation: typing.Union[int, str] = 'GLOBAL',
+              constraint_orientation: typing.Union[str, int] = 'GLOBAL',
               mirror: bool = False,
-              proportional: typing.Union[int, str] = 'DISABLED',
-              proportional_edit_falloff: typing.Union[int, str] = 'SMOOTH',
+              proportional: typing.Union[str, int] = 'DISABLED',
+              proportional_edit_falloff: typing.Union[str, int] = 'SMOOTH',
               proportional_size: float = 1.0,
               snap: bool = False,
-              snap_target: typing.Union[int, str] = 'CLOSEST',
+              snap_target: typing.Union[str, int] = 'CLOSEST',
               snap_point: typing.List[float] = (0.0, 0.0, 0.0),
               snap_align: bool = False,
               snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -772,19 +772,19 @@ def translate(value: typing.List[float] = (0.0, 0.0, 0.0),
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.List[bool]
     :param constraint_orientation: Orientation, Transformation orientation
-    :type constraint_orientation: typing.Union[int, str]
+    :type constraint_orientation: typing.Union[str, int]
     :param mirror: Mirror Editing
     :type mirror: bool
     :param proportional: Proportional Editing * DISABLED Disable, Proportional Editing disabled. * ENABLED Enable, Proportional Editing enabled. * PROJECTED Projected (2D), Proportional Editing using screen space locations. * CONNECTED Connected, Proportional Editing using connected geometry only.
-    :type proportional: typing.Union[int, str]
+    :type proportional: typing.Union[str, int]
     :param proportional_edit_falloff: Proportional Editing Falloff, Falloff type for proportional editing mode * SMOOTH Smooth, Smooth falloff. * SPHERE Sphere, Spherical falloff. * ROOT Root, Root falloff. * INVERSE_SQUARE Inverse Square, Inverse Square falloff. * SHARP Sharp, Sharp falloff. * LINEAR Linear, Linear falloff. * CONSTANT Constant, Constant falloff. * RANDOM Random, Random falloff.
-    :type proportional_edit_falloff: typing.Union[int, str]
+    :type proportional_edit_falloff: typing.Union[str, int]
     :param proportional_size: Proportional Size
     :type proportional_size: float
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
@@ -812,7 +812,7 @@ def vert_slide(value: float = 0.0,
                use_clamp: bool = True,
                mirror: bool = False,
                snap: bool = False,
-               snap_target: typing.Union[int, str] = 'CLOSEST',
+               snap_target: typing.Union[str, int] = 'CLOSEST',
                snap_point: typing.List[float] = (0.0, 0.0, 0.0),
                snap_align: bool = False,
                snap_normal: typing.List[float] = (0.0, 0.0, 0.0),
@@ -834,7 +834,7 @@ def vert_slide(value: float = 0.0,
     :param snap: Use Snapping Options
     :type snap: bool
     :param snap_target: Target * CLOSEST Closest, Snap closest point onto target. * CENTER Center, Snap center onto target. * MEDIAN Median, Snap median onto target. * ACTIVE Active, Snap active onto target.
-    :type snap_target: typing.Union[int, str]
+    :type snap_target: typing.Union[str, int]
     :param snap_point: Point
     :type snap_point: typing.List[float]
     :param snap_align: Align with Point Normal
