@@ -24,6 +24,7 @@ def BoolProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: 'bpy.types.BoolProperty'
     '''
 
     pass
@@ -55,6 +56,7 @@ def BoolVectorProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: typing.List['bpy.types.BoolProperty']
     '''
 
     pass
@@ -74,6 +76,7 @@ def CollectionProperty(
     :type description: str
     :param options: Enumerator in ['HIDDEN', 'SKIP_SAVE', 'ANIMATABLE', 'LIBRARY_EDITABLE', 'PROPORTIONAL','TEXTEDIT_UPDATE'].
     :type options: set
+    :rtype: 'bpy.types.CollectionProperty'
     '''
 
     pass
@@ -102,6 +105,7 @@ def EnumProperty(items: typing.List[str],
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: 'bpy.types.EnumProperty'
     '''
 
     pass
@@ -149,6 +153,7 @@ def FloatProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: 'bpy.types.FloatProperty'
     '''
 
     pass
@@ -201,6 +206,7 @@ def FloatVectorProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: typing.List['bpy.types.FloatProperty']
     '''
 
     pass
@@ -242,6 +248,7 @@ def IntProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: 'bpy.types.IntProperty'
     '''
 
     pass
@@ -288,6 +295,7 @@ def IntVectorProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: typing.List['bpy.types.IntProperty']
     '''
 
     pass
@@ -310,6 +318,7 @@ def PointerProperty(type=None,
     :type options: set
     :param poll: function to be called to determine whether an item is valid for this property. The function must take 2 values (self, object) and return Bool.
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
+    :rtype: 'bpy.types.PointerProperty'
     '''
 
     pass
@@ -352,6 +361,7 @@ def StringProperty(name: str = "",
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     :param get: Function to be called when this value is 'read', This function must take 1 value (self) and return the value of the property.
     :param set: Function to be called when this value is 'written', This function must take 2 values (self, value) and return None.
+    :rtype: 'bpy.types.StringProperty'
     '''
 
     pass
