@@ -1,7 +1,7 @@
 import sys
 import typing
-from . import units
 from . import previews
+from . import units
 
 
 def app_template_paths(subdir: str = None):
@@ -26,6 +26,7 @@ def blend_paths(absolute: bool = False,
     :type packed: bool
     :param local: When true skip linked library paths.
     :type local: bool
+    :rtype: list
     :return: path list.
     '''
 
@@ -37,6 +38,7 @@ def escape_identifier(string: str) -> str:
 
     :param string: text
     :type string: str
+    :rtype: str
     :return: The escaped string.
     '''
 
@@ -72,6 +74,7 @@ def make_rna_paths(struct_name: str, prop_name: str, enum_name: str) -> tuple:
     :type prop_name: str
     :param enum_name: Name of a RNA enum identifier.
     :type enum_name: str
+    :rtype: tuple
     :return: A triple of three "RNA paths" (most_complete_path, "struct.prop", "struct.prop:'enum'"). If no enum_name is given, the third element will always be void.
     '''
 
@@ -93,6 +96,7 @@ def modules_from_path(path: str, loaded_modules: set) -> list:
     :type path: str
     :param loaded_modules: already loaded module names, files matching these names will be ignored.
     :type loaded_modules: set
+    :rtype: list
     :return: all loaded modules.
     '''
 
@@ -112,6 +116,7 @@ def preset_paths(subdir: str) -> list:
 
     :param subdir: preset subdirectory (must not be an absolute path).
     :type subdir: str
+    :rtype: list
     :return: script paths.
     '''
 
@@ -158,6 +163,7 @@ def register_submodule_factory(module_name: str,
     :type module_name: str
     :param submodule_names: List of submodule names to load and unload.
     :type submodule_names: list
+    :rtype: tuple
     :return: register and unregister functions.
     '''
 
@@ -175,6 +181,7 @@ def resource_path(type: str,
     :type major: int
     :param minor: minor version, defaults to current.
     :type minor: str
+    :rtype: str
     :return: the resource path (not necessarily existing).
     '''
 
@@ -209,6 +216,7 @@ def script_paths(subdir: str = None,
     :type user_pref: bool
     :param check_all: Include local, user and system paths rather just the paths blender uses.
     :type check_all: bool
+    :rtype: list
     :return: script paths.
     '''
 
@@ -220,6 +228,7 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
 
     :param frame: frame number.
     :type frame: int
+    :rtype: str
     :return: the frame string.
     '''
 
@@ -231,6 +240,7 @@ def smpte_from_seconds(time: typing.Union[float, int], fps=None) -> str:
 
     :param time: time in seconds.
     :type time: typing.Union[float, int]
+    :rtype: str
     :return: the frame string.
     '''
 
@@ -286,6 +296,7 @@ def user_resource(resource_type, path='', create: bool = False) -> str:
     :type subdir: str
     :param create: Treat the path as a directory and create it if its not existing.
     :type create: bool
+    :rtype: str
     :return: a path.
     '''
 
