@@ -6,6 +6,7 @@ import bpy.types
 def edge_face_count(mesh) -> list:
     ''' 
 
+    :rtype: list
     :return: list face users for each item in mesh.edges.
     '''
 
@@ -15,6 +16,7 @@ def edge_face_count(mesh) -> list:
 def edge_face_count_dict(mesh) -> dict:
     ''' 
 
+    :rtype: dict
     :return: dict of edge keys with their value set to the number of faces using each edge.
     '''
 
@@ -39,6 +41,7 @@ def edge_loops_from_tessfaces(
     :type mesh: 'bpy.types.Mesh'
     :param tessfaces: optional face list to only use some of the meshes faces.
     :type tessfaces: typing.List['bpy.types.MeshTessFace']
+    :rtype: list
     :return: return a list of edge vertex index lists.
     '''
 
@@ -51,6 +54,7 @@ def face_random_points(
 
     :param tessfaces: list of the faces to generate points on.
     :type tessfaces: typing.List['bpy.types.MeshTessFace']
+    :rtype: list
     :return: list of random points over all faces.
     '''
 
@@ -62,6 +66,7 @@ def mesh_linked_tessfaces(mesh: 'bpy.types.Mesh') -> list:
 
     :param mesh: the mesh used to group with.
     :type mesh: 'bpy.types.Mesh'
+    :rtype: list
     :return: lists of lists containing faces.
     '''
 
@@ -73,6 +78,7 @@ def mesh_linked_uv_islands(mesh: 'bpy.types.Mesh') -> list:
 
     :param mesh: the mesh used to group with.
     :type mesh: 'bpy.types.Mesh'
+    :rtype: list
     :return: lists of lists containing polygon indices
     '''
 
